@@ -5,7 +5,7 @@ CosmicCalculator is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2022 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -191,8 +191,8 @@ struct argp_option program_options[] =
       ui_add_to_single_value,
     },
     {
-      "angulardimdist",
-      UI_KEY_ANGULARDIMDIST,
+      "angulardiamdist",
+      UI_KEY_ANGULARDIAMDIST,
       0,
       0,
       "Angular diameter distance (Mpc).",
@@ -346,7 +346,7 @@ struct argp_option program_options[] =
       UI_KEY_LISTLINES,
       0,
       0,
-      "List known lines and rest frame wavelength.",
+      "List pre-defined lines at rest frame.",
       UI_GROUP_SPECTRAL_LINES,
       &p->listlines,
       GAL_OPTIONS_NO_ARG_TYPE,
@@ -359,7 +359,7 @@ struct argp_option program_options[] =
       UI_KEY_LISTLINESATZ,
       0,
       0,
-      "List known spectral lines at given redshift.",
+      "List pre-defined lines at the given redshift.",
       UI_GROUP_SPECTRAL_LINES,
       &p->listlinesatz,
       GAL_OPTIONS_NO_ARG_TYPE,
@@ -367,6 +367,19 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
+    {
+      "lineunit",
+      UI_KEY_LINEUNIT,
+      "STR",
+      0,
+      "Unit ('angstrom', 'nm', 'microm' or 'm').",
+      UI_GROUP_SPECTRAL_LINES,
+      &p->lineunit,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+    },
     {
       "lineatz",
       UI_KEY_LINEATZ,
@@ -382,8 +395,6 @@ struct argp_option program_options[] =
       ui_add_to_single_value,
     },
 
-
-
     {0}
   };
 
