@@ -6,7 +6,7 @@ Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
      Pedram Ashofteh-Ardakani <pedramardakani@pm.me>
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -29,9 +29,11 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <stdio.h>
 #include <string.h>
 
+#include <gnuastro/txt.h>
 #include <gnuastro/wcs.h>
 #include <gnuastro/fits.h>
 
+
 #include <gnuastro-internal/options.h>
 #include <gnuastro-internal/checkset.h>
 #include <gnuastro-internal/fixedstringmacros.h>
@@ -469,9 +471,9 @@ ui_read_check_mode_extension(struct fitsparams *p)
   uint8_t stdoutcheck=0;
 
   if( p->remove || p->copy || p->cut || p->numhdus || p->datasum
-      || p->pixelscale || p->pixelareaarcsec2 || p->skycoverage
-      || p->hastablehdu || p->hasimagehdu || p->listtablehdus
-      || p->listimagehdus )
+      || p->datasumencoded || p->pixelscale || p->pixelareaarcsec2
+      || p->skycoverage || p->hastablehdu || p->hasimagehdu
+      || p->listtablehdus || p->listimagehdus )
     {
       /* A small sanity check. */
       if(p->mode!=FITS_MODE_INVALID)
@@ -479,10 +481,10 @@ ui_read_check_mode_extension(struct fitsparams *p)
               "cannot be called together");
 
       /* Some HDU options cannot be called with other options. */
-      stdoutcheck = ( p->numhdus + p->datasum + p->pixelscale
-                      + p->pixelareaarcsec2 + p->skycoverage
-                      + p->hastablehdu + p->hasimagehdu + p->listtablehdus
-                      + p->listimagehdus );
+      stdoutcheck = ( p->numhdus + p->datasum + p->datasumencoded
+                      + p->pixelscale + p->pixelareaarcsec2
+                      + p->skycoverage + p->hastablehdu + p->hasimagehdu
+                      + p->listtablehdus + p->listimagehdus );
 
       /* Make sure if an output file is needed. */
       if(stdoutcheck)
@@ -561,17 +563,35 @@ ui_check_only_options(struct fitsparams *p)
 static void
 ui_check_options_and_arguments(struct fitsparams *p)
 {
-  /* Make sure an input file name was given and if it was a FITS file, that
-     a HDU is also given. */
-  if(p->input==NULL)
-    error(EXIT_FAILURE, 0, "no input file is specified");
-  gal_list_str_reverse(&p->input);
 
-  /* More than one input is currently only acceptable with the '--keyvalue'
-     option. */
-  if( gal_list_str_number(p->input) > 1 && p->keyvalue==NULL)
-    error(EXIT_FAILURE, 0, "one input file is expected but %zu input "
-          "files are given", gal_list_str_number(p->input));
+
+  /* Other than the '--keyvalue' option, the rest of the operations only
+     require a single file. */
+  if(p->keyvalue)
+    {
+      /* If '--arguments' is given and there is no input files, read the
+         names of the inputs from that. Otherwose, complain about not
+         having any input.*/
+      if(p->input==NULL)
+        {
+          if(p->arguments)
+            p->input=gal_txt_read_to_list(p->arguments);
+          else
+            error(EXIT_FAILURE, 0, "no input file(s) specified");
+        }
+    }
+  else
+    {
+      /* If there are any inputs. */
+      if(p->input==NULL)
+        error(EXIT_FAILURE, 0, "no input file is specified");
+      gal_list_str_reverse(&p->input);
+
+      /* Only one input. */
+      if( gal_list_str_number(p->input) > 1)
+        error(EXIT_FAILURE, 0, "one input file is expected but %zu input "
+              "files are given", gal_list_str_number(p->input));
+    }
 }
 
 
@@ -672,7 +692,8 @@ ui_fill_fits_headerll(gal_list_str_t *input, gal_fits_list_key_t **output,
       if(keyname)
         {
           if( !strcasecmp(keyname,"checksum")
-              || !strcasecmp(keyname,"datasum") )
+              || !strcasecmp(keyname,"datasum")
+              || !strcasecmp(keyname,"datasum-encoded"))
             needsvalue=0;
         }
 
