@@ -5,7 +5,7 @@ MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -151,7 +151,7 @@ saveindividual(struct mkonthread *mkp)
   /* Write the array to the file (a separately built PSF doesn't need WCS
      coordinates). */
   if(ibq->ispsf && p->psfinimg==0)
-    gal_fits_img_write(ibq->image, filename, NULL, PROGRAM_NAME);
+    gal_fits_img_write(ibq->image, filename, NULL, 0);
   else
     {
       /* Allocate space for the corrected crpix and fill it in. Both
@@ -159,17 +159,20 @@ saveindividual(struct mkonthread *mkp)
       crpix=gal_pointer_allocate(GAL_TYPE_FLOAT64, ndim, 0, __func__,
                                  "crpix");
       for(i=0;i<ndim;++i)
-        crpix[i] = ((double *)(p->crpix->array))[i] - os*(mkp->fpixel_i[i]-1);
+        crpix[i] = ( ((double *)(p->crpix->array))[i]
+                     - os*(mkp->fpixel_i[i]-1) );
 
       /* Write the image. */
       gal_fits_img_write_corr_wcs_str(ibq->image, filename, p->wcsstr,
-                                      p->wcsnkeyrec, crpix, NULL,
-                                      PROGRAM_NAME);
+                                      p->wcsnkeyrec, crpix, NULL, 0);
     }
   ibq->indivcreated=1;
 
 
-  /* Write profile settings into the FITS file. */
+  /* Write profile settings into a keyword list. */
+  gal_fits_key_list_title_add(&keys, "Profile configuration", 0);
+  gal_fits_key_list_add(&keys, GAL_TYPE_STRING, "EXTNAME", 0,
+                        "PROFILE-CONFIG", 0, "HDU name", 0, NULL, 0);
   gal_fits_key_list_add(&keys, GAL_TYPE_STRING, "PROFILE", 0,
                         ui_profile_name_write(mkp->func), 0,
                         "Radial function", 0, NULL, 0);
@@ -265,9 +268,10 @@ saveindividual(struct mkonthread *mkp)
                         &p->magatpeak, 0, "Magnitude is for peak pixel, "
                         "not full profile", 0, NULL, 0);
 
+
+  /* Write the keyword list into the output file. */
   gal_fits_key_list_reverse(&keys);
-  gal_fits_key_write_config(&keys, "Profile configuration", "PROFILE-CONFIG",
-                            filename, "0");
+  gal_fits_key_write(keys, filename, "0", "NONE", 1, 0);
 
 
   /* Report if in verbose mode. */
@@ -485,6 +489,7 @@ mkprof_build(void *inparam)
 {
   struct mkonthread *mkp=(struct mkonthread *)inparam;
   struct mkprofparams *p=mkp->p;
+
   size_t i, id, ndim=p->ndim;
   struct builtqueue *ibq, *fbq=NULL;
   double center[3], semiaxes[3], euler_deg[3];
@@ -505,18 +510,23 @@ mkprof_build(void *inparam)
       id=ibq->id=mkp->indexs[i];
       if(fbq==NULL) fbq=ibq;
 
-
       /* Write the necessary parameters for this profile into 'mkp'.*/
       oneprofile_set_prof_params(mkp);
 
-
       /* Find the bounding box size (NOT oversampled). */
       if( p->f[id] == PROFILE_POINT )
-        mkp->width[0]=mkp->width[1]=1;
+        {
+          mkp->width[0]=mkp->width[1]=1;
+          if(ndim==3) mkp->width[2]=1;
+        }
       else if( p->f[id] == PROFILE_CUSTOM_IMG )
         {
           mkp->width[0]=mkp->customimg->dsize[1]; /* 'width' is in */
           mkp->width[1]=mkp->customimg->dsize[0]; /* FITS order not C. */
+          if(ndim==3)
+            error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at "
+                  "'%s' to fix the problem. Custom images are not yet "
+                  "supported for 3D inputs", __func__, PACKAGE_BUGREPORT);
         }
       else
         switch(ndim)
@@ -702,23 +712,22 @@ mkprof_write(struct mkprofparams *p)
       /* Get the current time for verbose output. */
       if(!p->cp.quiet) gettimeofday(&t1, NULL);
 
+      /* Write the configuration keywords. */
+      gal_fits_key_write_filename("input", p->catname, &p->cp.ckeys, 1,
+                                  p->cp.quiet);
+      gal_fits_key_write(p->cp.ckeys, p->mergedimgname, "0", "NONE", 1, 1);
+
       /* Write the final image into a FITS file with the requested
          type. Until now, we were using 'p->wcs' for the WCS, but from now
          on, will put it in 'out' to also free it while freeing 'out'. */
       out->wcs=p->wcs;
       gal_fits_img_write_to_type(out, p->mergedimgname, NULL,
-                                 PROGRAM_NAME, p->cp.type);
+                                 p->cp.type, 0);
       p->wcs=NULL;
 
       /* Clean up */
       gal_data_free(out);
 
-      /* Write the configuration keywords. */
-      gal_fits_key_write_filename("input", p->catname, &p->cp.okeys, 1,
-                                  p->cp.quiet);
-      gal_fits_key_write_config(&p->cp.okeys, "MakeProfiles configuration",
-                                "MKPROF-CONFIG", p->mergedimgname, "0");
-
       /* In verbose mode, print the information. */
       if(!p->cp.quiet)
         {
@@ -750,7 +759,7 @@ mkprof_write(struct mkprofparams *p)
 
 
 /**************************************************************/
-/************           Outside function          *************/
+/************         Top-level function          *************/
 /**************************************************************/
 void
 mkprof(struct mkprofparams *p)
@@ -790,7 +799,8 @@ mkprof(struct mkprofparams *p)
      ignore it. */
   if(p->out)
     {
-      onaxes=gal_pointer_allocate(GAL_TYPE_LONG, ndim, 0, __func__, "onaxes");
+      onaxes=gal_pointer_allocate(GAL_TYPE_LONG, ndim, 0, __func__,
+                                  "onaxes");
       for(fi=0; fi < ndim; ++fi)
         {
           i=ndim-fi-1;
@@ -820,10 +830,11 @@ mkprof(struct mkprofparams *p)
 
       /* Initialize the condition variable and mutex. */
       err=pthread_mutex_init(&p->qlock, NULL);
-      if(err) error(EXIT_FAILURE, 0, "%s: mutex not initialized", __func__);
-      err=pthread_cond_init(&p->qready, NULL);
-      if(err) error(EXIT_FAILURE, 0, "%s: condition variable not initialized",
+      if(err) error(EXIT_FAILURE, 0, "%s: mutex not initialized",
                     __func__);
+      err=pthread_cond_init(&p->qready, NULL);
+      if(err) error(EXIT_FAILURE, 0, "%s: condition variable not "
+                    "initialized", __func__);
 
       /* Spin off the threads: */
       for(i=0;i<nt;++i)
