@@ -5,7 +5,7 @@ NoiseChisel is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2023 Free Software Foundation, Inc.
+Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -537,12 +537,12 @@ ui_prepare_tiles(struct noisechiselparams *p)
     {
       /* Large tiles. */
       check=gal_tile_block_check_tiles(ltl->tiles);
-      gal_fits_img_write(check, tl->tilecheckname, NULL, PROGRAM_NAME);
+      gal_fits_img_write(check, tl->tilecheckname, NULL, 0);
       gal_data_free(check);
 
       /* Small tiles. */
       check=gal_tile_block_check_tiles(tl->tiles);
-      gal_fits_img_write(check, tl->tilecheckname, NULL, PROGRAM_NAME);
+      gal_fits_img_write(check, tl->tilecheckname, NULL, 0);
       gal_data_free(check);
 
       /* If 'continueaftercheck' hasn't been called, abort NoiseChisel. */
