@@ -5,7 +5,7 @@ Query is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2020, Free Software Foundation, Inc.
+Copyright (C) 2020-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -28,7 +28,10 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 enum query_databases
 {
   QUERY_DATABASE_INVALID,
+  QUERY_DATABASE_ASTRON,
   QUERY_DATABASE_GAIA,
+  QUERY_DATABASE_NED,
+  QUERY_DATABASE_VIZIER,
 };
 
 
