@@ -5,7 +5,7 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2023 Free Software Foundation, Inc.
+Copyright (C) 2016-2024 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -1628,6 +1628,55 @@ gal_txt_stdin_read(long timeout_microsec)
 
 
 
+gal_list_str_t *
+gal_txt_read_to_list(char *filename)
+{
+  FILE *fp;
+  gal_list_str_t *out=NULL;
+  char *line, *format_err="empty";
+  size_t linelen=10; /* 'linelen' will be increased by 'getline'. */
+
+  /* Make sure an input filename is given. */
+  if(filename==NULL) return NULL;
+
+  /* Open the file. */
+  errno=0;
+  fp=fopen(filename, "r");
+  if(fp==NULL)
+    error(EXIT_FAILURE, errno, "%s: couldn't open to read as a plain "
+          "text %s (from Gnuastro's '%s')", filename, format_err,
+          __func__);
+
+  /* Allocate the space necessary to keep each line as we parse it. Note
+     that 'getline' is going to later 'realloc' this space to fit the line
+     length. */
+  errno=0;
+  line=malloc(linelen*sizeof *line);
+  if(line==NULL)
+    error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for line",
+          __func__, linelen*sizeof *line);
+
+
+  /* Read the comments of the line for possible information about the
+     lines, but also confirm/complete the info by parsing the first
+     uncommented line. */
+  while( getline(&line, &linelen, fp) != -1 )
+    {
+      if(out==NULL)
+        out=gal_list_str_extract(line);
+      else
+        gal_list_str_last(out)->next=gal_list_str_extract(line);
+    }
+
+  /* Return the output. */
+  return out;
+}
+
+
+
+
+
+
 
 
 
@@ -1918,13 +1967,14 @@ txt_write_metadata(FILE *fp, gal_data_t *datall, char **fmts,
 
 
 static void
-txt_write_keys(FILE *fp, struct gal_fits_list_key_t **keylist)
+txt_write_keys(FILE *fp, struct gal_fits_list_key_t *keylist,
+               int freekeys)
 {
   char *ending;
   char *valuestr;
   gal_fits_list_key_t *tmp, *ttmp;
 
-  tmp=*keylist;
+  tmp=keylist;
   while(tmp!=NULL)
     {
       /* If a title is requested, only put a title. */
@@ -1981,9 +2031,6 @@ txt_write_keys(FILE *fp, struct gal_fits_list_key_t **keylist)
       free(tmp);
       tmp=ttmp;
     }
-
-  /* Set it to NULL so it isn't mistakenly used later. */
-  *keylist=NULL;
 }
 
 
@@ -1991,9 +2038,9 @@ txt_write_keys(FILE *fp, struct gal_fits_list_key_t **keylist)
 
 
 void
-gal_txt_write(gal_data_t *input, struct gal_fits_list_key_t **keylist,
+gal_txt_write(gal_data_t *input, struct gal_fits_list_key_t *keylist,
               gal_list_str_t *comment, char *filename,
-              uint8_t colinfoinstdout, int tab0_img1)
+              uint8_t colinfoinstdout, int tab0_img1, int freekeys)
 {
   FILE *fp;
   char **fmts;
@@ -2070,7 +2117,7 @@ gal_txt_write(gal_data_t *input, struct gal_fits_list_key_t **keylist,
         fprintf(fp, "# %s\n", strt->v);
 
       /* Write the keywords. */
-      if(keylist) txt_write_keys(fp, keylist);
+      if(keylist) txt_write_keys(fp, keylist, freekeys);
     }
   else
     fp=stdout;
